@@ -54,6 +54,7 @@ const project = new cdk.JsiiProject({
     dotNetNamespace: 'Marciocadev.Examples',
     packageId: 'Projen.Jsii',
   },
+  publishTasks: true,
   // generate docs
   docgen: true,
   eslint: true,
@@ -65,7 +66,7 @@ const project = new cdk.JsiiProject({
 });
 
 project.addDevDeps('typedoc');
-project.addTask('docgen:ts', {
+project.addTask('docgen:html', {
   exec: 'typedoc src --disableSources --out docs/',
 });
 
